summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/styles/tqwindowsstyle.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/styles/tqwindowsstyle.cpp')
-rw-r--r--tqtinterface/qt4/src/styles/tqwindowsstyle.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/tqtinterface/qt4/src/styles/tqwindowsstyle.cpp b/tqtinterface/qt4/src/styles/tqwindowsstyle.cpp
index aa65a5b..5a25f3d 100644
--- a/tqtinterface/qt4/src/styles/tqwindowsstyle.cpp
+++ b/tqtinterface/qt4/src/styles/tqwindowsstyle.cpp
@@ -121,7 +121,7 @@ TQWindowsStyle::Private::Private(TQWindowsStyle *tqparent)
bool TQWindowsStyle::Private::hasSeenAlt(const TQWidget *widget) const
{
widget = widget->tqtopLevelWidget();
- return seenAlt.tqcontains(widget);
+ return seenAlt.contains(widget);
}
// Records Alt- and Focus events
@@ -137,7 +137,7 @@ bool TQWindowsStyle::Private::eventFilter(TQObject *o, TQEvent *e)
if (((TQKeyEvent*)e)->key() == Qt::Key_Alt) {
widget = widget->tqtopLevelWidget();
// Alt has been pressed - tqfind all widgets that care
TQObjectList *l = widget->queryList("TQWidget");
TQObjectListIt it( *l );
TQWidget *w;
@@ -976,7 +976,7 @@ void TQWindowsStyle::tqdrawControl( TQ_ControlElement element,
}
TQString s = mi->text();
if ( !s.isNull() ) { // draw text
- int t = s.tqfind( '\t' );
+ int t = s.find( '\t' );
int text_flags = TQt::AlignVCenter|TQt::ShowPrefix | TQt::DontClip | TQt::SingleLine;
if (!tqstyleHint(SH_UnderlineAccelerator, widget))
text_flags |= TQt::NoAccel;
@@ -1232,7 +1232,7 @@ TQSize TQWindowsStyle::tqsizeFromContents( ContentsType contents,
2*windowsItemFrame);
}
- if (! mi->text().isNull() && mi->text().tqfind('\t') >= 0) {
+ if (! mi->text().isNull() && mi->text().find('\t') >= 0) {
if ( use2000style )
w += 20;
else
@@ -137,7 +137,7 @@ bool TQWindowsStyle::Private::eventFilter(TQObject *o, TQEvent *e)
if (((TQKeyEvent*)e)->key() == Qt::Key_Alt) {
widget = widget->tqtopLevelWidget();
- // Alt has been pressed - tqfind all widgets that care
+ // Alt has been pressed - find all widgets that care
TQObjectList *l = widget->queryList("TQWidget");
TQObjectListIt it( *l );